@@ -16,6 +16,8 @@ limitations under the License.
 
 import os
 import logging
+
+from . import consts
 from distutils.util import strtobool
 from typing import Optional, Dict
 
@@ -74,52 +76,61 @@ class Options:
         debug: bool = None,
         payloads_enabled: bool = None,
         max_payload_size: int = None,
+        disable_instrumentations: bool = None,
         exporters: [ExporterOptions] = None,
     ):
 
+        # Set options parameters
+        self.service_name = service_name or os.environ.get(
+            Consts.SERVICE_NAME_KEY, Consts.DEFAULT_SERVICE_NAME
+        )
         self.cisco_token = cisco_token or os.environ.get(Consts.CISCO_TOKEN_ENV)
-        if self.cisco_token is None and exporters is None:
-            raise ValueError("Can not initiate cisco-telescope without token")
 
-        if self.cisco_token is not None and exporters is not None:
-            logging.warning(
-                "Warning: Custom exporters do not use cisco token, it can be passed as a custom header"
+        self.debug = (
+            debug
+            if debug is not None
+            else strtobool(
+                os.environ.get(Consts.CISCO_DEBUG_ENV, str(Consts.DEFAULT_CISCO_DEBUG))
             )
+        )
 
-        if not exporters or len(exporters) == 0:  # Set default exporter
-            self.exporters = [
-                ExporterOptions(
-                    exporter_type=Consts.DEFAULT_EXPORTER_TYPE,
-                    collector_endpoint=Consts.DEFAULT_COLLECTOR_ENDPOINT,
-                    custom_headers={
-                        Consts.TOKEN_HEADER_KEY: verify_token(self.cisco_token)
-                    },
-                )
-            ]
-        else:
-            self.exporters = exporters
-
-        self.service_name = service_name
-
-        if payloads_enabled is None:
-            self.payloads_enabled = strtobool(
+        self.payloads_enabled = (
+            payloads_enabled
+            if payloads_enabled is not None
+            else strtobool(
                 os.environ.get(
                     Consts.CISCO_PAYLOADS_ENABLED_ENV,
                     str(Consts.DEFAULT_PAYLOADS_ENABLED),
                 )
             )
-        else:
-            self.payloads_enabled = payloads_enabled
+        )
 
-        if debug is None:
-            self.debug = strtobool(
-                os.environ.get(Consts.CISCO_DEBUG_ENV, str(Consts.DEFAULT_CISCO_DEBUG))
+        self.disable_instrumentations = (
+            disable_instrumentations
+            if disable_instrumentations is not None
+            else strtobool(
+                os.environ.get(
+                    Consts.CISCO_DISABLE_INSTRUMENTATIONS_ENV,
+                    str(Consts.DEFAULT_DISABLE_INSTRUMENTATIONS),
+                )
             )
-        else:
-            self.debug = debug
+        )
 
         self.max_payload_size = max_payload_size or Consts.DEFAULT_MAX_PAYLOAD_SIZE
 
+        self.exporters = exporters or [
+            ExporterOptions(
+                exporter_type=Consts.DEFAULT_EXPORTER_TYPE,
+                collector_endpoint=Consts.DEFAULT_COLLECTOR_ENDPOINT,
+                custom_headers={
+                    Consts.TOKEN_HEADER_KEY: verify_token(self.cisco_token)
+                },
+            )
+        ]
+
+        self._set_debug()
+        self._validate_params(exporters)
+
     def __str__(self):
         return (
             f"\n{self.__class__.__name__}(\n\t"
@@ -129,10 +140,43 @@ class Options:
             f"exporters: \n\t{', '.join(map(str, self.exporters))})"
         )
 
+    def _validate_params(self, exporters):
+        if self.cisco_token is None and exporters is None:
+            raise ValueError("Can not initiate cisco-telescope without token")
+
+        if self.cisco_token and exporters is not None:
+            logging.warning(
+                "Warning: Custom exporters do not use cisco token, it can be passed as a custom header"
+            )
+
+        if self.disable_instrumentations:
+            logging.warning("Warning: All Telescope instrumentations are disabled")
+
+    def _set_debug(self):
+        """
+        Log spans to console, set global logging to debug level
+        """
+        if self.debug:
+            logging.basicConfig(
+                level=logging.DEBUG,
+                format="%(asctime)s %(levelname)-8s %(filename)s:%(funcName)s:%(lineno)s - %(message)s",
+                datefmt="%Y-%m-%d %H:%M:%S",
+            )
+
+            logging.debug(
+                "Log level is set to debug, spans will sent and printed to console"
+            )
+
+            self.exporters.append(
+                ExporterOptions(exporter_type=consts.CONSOLE_EXPORTER_TYPE)
+            )
+
 
 def verify_token(token: str) -> str:
     auth_prefix = "Bearer "
-    if token.startswith(auth_prefix):
+    if not token:
+        return ""
+    if token and token.startswith(auth_prefix):
         return token
     else:
         return auth_prefix + token
